function [result,time]=CalcEnergy(Ej_v,Ec_v,alpha_v,f_v,nmax_v,ng1_v,ng2_v,nelevels)
% [result,time]=CalcEnergy(Ej,Ec,alpha,f,nmax,ng1,ng2,nelevels)
%     Ej - Josephson energy E_j=\frac{I_c \phi_0}{2 \pi}
%     Ec - charging energy E_c=\frac{e^2}{2 C}
%     alpha - relative size of the top junction compared to the left and right junctions
%     f - frustration f=\frac{B A}{\phi_0}
%     nmax - maximum number of cooper pairs on an island - charge states run from -nmax to nmax
%     ng1 - gate charge induced on island 1 (top left island)
%     ng2 - gate charge induced on island 2 (top right island)
%     nelevels - number of lowest energy levels
%
% all input parameters (beside nelevels) can also be given as vectors.
%
%    result has the form: Ej, Ec, alpha, f, nmax, ng1, ng2, E0, E1, E2, ...
%    time hast the form:  expired time (sec), percentage done
%
% Example:
%    [result,time]=CalcEnergy(1,1/80,0.8,[0.45:0.001:0.5],6,0,0,5);
%    plot(result(4,:),result(8:12,:),'.');
%
% CalcEnergy 1.0  2.10.2001  Hannes Majer (majer@qt.tn.tudelft.nl)

result=[];
time=[];

Ej_n=length(Ej_v);
Ec_n=length(Ec_v);
alpha_n=length(alpha_v);
f_n=length(f_v);
nmax_n=length(nmax_v);
ng1_n=length(ng1_v);
ng2_n=length(ng2_v);

wb = waitbar(0,'Please wait...');
tic;

for Ej_c=1:Ej_n
   Ej=Ej_v(Ej_c);
   for Ec_c=1:Ec_n
      Ec=Ec_v(Ec_c);
      for alpha_c=1:alpha_n
         alpha=alpha_v(alpha_c);
         for f_c=1:f_n
            f=f_v(f_c);
            for nmax_c=1:nmax_n
               nmax=nmax_v(nmax_c);
               for ng1_c=1:ng1_n
                  ng1=ng1_v(ng1_c);
                  for ng2_c=1:ng2_n
                     ng2=ng2_v(ng2_c);
                     
                     disp(['Ej = 'num2str(Ej) ' Ec = 'num2str(Ec) ' alpha = ' num2str(alpha) ' f = ' num2str(f) ' nmax = ' num2str(nmax) ' ng1 = ' num2str(ng1) ' ng2 = ' num2str(ng2)])
                     
                     H=QubitHamiltonian(Ej,Ec,alpha,f,nmax,ng1,ng2);
                     elevels=eig(H);
                     elevels=sort(real(elevels));
                     EnergyLevels=elevels(1:nelevels);
                     
                     result=[result [Ej;Ec;alpha;f;nmax;ng1;ng2;EnergyLevels]];
                     
                     counter=ng2_c; 
                     counter=counter + (ng1_c-1)*ng2_n;
                     counter=counter + (nmax_c-1)*ng2_n*ng1_n;
                     counter=counter + (f_c-1)*nmax_n*ng2_n*ng1_n;
                     counter=counter + (alpha_c-1)*f_n*nmax_n*ng2_n*ng1_n;
                     counter=counter + (Ec_c-1)*alpha_n*f_n*nmax_n*ng2_n*ng1_n;
                     counter=counter + (Ej_c-1)*Ec_n*alpha_n*f_n*nmax_n*ng2_n*ng1_n;
                     done=counter/(Ej_n*Ec_n*alpha_n*f_n*nmax_n*ng2_n*ng1_n);
							waitbar(done);
                     
                     time=[time [toc;done]];
                     
                     ttg=round(toc/done-toc);
                     disp([num2str(done*100,'%0.1f') '% done, ' num2str(floor(ttg/60)) ' minutes ' num2str(rem(ttg,60)) ' seconds to go']);
                     disp(' ');
                  end
               end
            end
         end
      end
   end
end
close(wb)
